@@ -14,7 +14,7 @@ use FileHandle          ();
 use vars qw( $VERSION @ISA );
 
 BEGIN {
-    $VERSION = '1.47';
+    $VERSION = '1.49';
 
     require Exporter;
     @ISA = qw( Exporter );
@@ -109,21 +109,35 @@ BEGIN {
             qw(
               SIGNATURE_FORMAT
               SIGNATURE_LENGTH
+
               LOCAL_FILE_HEADER_SIGNATURE
               LOCAL_FILE_HEADER_FORMAT
               LOCAL_FILE_HEADER_LENGTH
-              CENTRAL_DIRECTORY_FILE_HEADER_SIGNATURE
+
+              DATA_DESCRIPTOR_SIGNATURE
               DATA_DESCRIPTOR_FORMAT
               DATA_DESCRIPTOR_LENGTH
-              DATA_DESCRIPTOR_SIGNATURE
+
               DATA_DESCRIPTOR_FORMAT_NO_SIG
               DATA_DESCRIPTOR_LENGTH_NO_SIG
+
+              CENTRAL_DIRECTORY_FILE_HEADER_SIGNATURE
               CENTRAL_DIRECTORY_FILE_HEADER_FORMAT
               CENTRAL_DIRECTORY_FILE_HEADER_LENGTH
+
+              ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIGNATURE
+              ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_FORMAT
+              ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_LENGTH
+
+              ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIGNATURE
+              ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_FORMAT
+              ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_LENGTH
+
               END_OF_CENTRAL_DIRECTORY_SIGNATURE
-              END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING
               END_OF_CENTRAL_DIRECTORY_FORMAT
               END_OF_CENTRAL_DIRECTORY_LENGTH
+
+              END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING
               )
         ],
 
@@ -240,6 +254,16 @@ use constant CENTRAL_DIRECTORY_FILE_HEADER_SIGNATURE => 0x02014b50;
 use constant CENTRAL_DIRECTORY_FILE_HEADER_FORMAT    => "C2 v3 V4 v5 V2";
 use constant CENTRAL_DIRECTORY_FILE_HEADER_LENGTH    => 42;
 
+# zip64 support
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIGNATURE => 0x06064b50;
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_FORMAT => 0;
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_LENGTH => 0;
+
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIGNATURE => 0x07064b50;
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_FORMAT => 0;
+use constant ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_LENGTH => 0;
+
+
 use constant END_OF_CENTRAL_DIRECTORY_SIGNATURE => 0x06054b50;
 use constant END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING =>
   pack("V", END_OF_CENTRAL_DIRECTORY_SIGNATURE);
@@ -461,7 +485,10 @@ sub _readSignature {
             && $signature != CENTRAL_DIRECTORY_FILE_HEADER_SIGNATURE
             && $signature != LOCAL_FILE_HEADER_SIGNATURE
             && $signature != END_OF_CENTRAL_DIRECTORY_SIGNATURE
-            && $signature != DATA_DESCRIPTOR_SIGNATURE)
+            && $signature != DATA_DESCRIPTOR_SIGNATURE
+            && $signature != ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIGNATURE
+            && $signature != ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIGNATURE
+        )
       ) {
         my $errmsg = sprintf("bad signature: 0x%08x", $signature);
         if (_isSeekable($fh)) {
